aboutsummaryrefslogtreecommitdiff
path: root/pthreads/tests/cancel6d.c
diff options
context:
space:
mode:
Diffstat (limited to 'pthreads/tests/cancel6d.c')
-rw-r--r--pthreads/tests/cancel6d.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/pthreads/tests/cancel6d.c b/pthreads/tests/cancel6d.c
index 37f9ca5f3..f94ed5ac8 100644
--- a/pthreads/tests/cancel6d.c
+++ b/pthreads/tests/cancel6d.c
@@ -24,9 +24,9 @@
*
* --------------------------------------------------------------------------
*
* Test Synopsis: Test double cancelation - deferred.
* Second attempt should succeed (unless the canceled thread has started
* cancelation already - not tested here).
*
* Test Method (Validation or Falsification):
* -
@@ -101,7 +101,7 @@ mythread(void * arg)
/*
* We wait up to 10 seconds, waking every 0.1 seconds,
* for a cancelation to be applied to us.
*/
for (bag->count = 0; bag->count < 100; bag->count++)
{
@@ -129,7 +129,7 @@ main()
}
/*
- * Code to control or munipulate child threads should probably go here.
+ * Code to control or manipulate child threads should probably go here.
*/
Sleep(500);
@@ -138,7 +138,7 @@ main()
assert(pthread_cancel(t[i]) == 0);
if (pthread_cancel(t[i]) != 0)
{
- printf("Second cancelation failed but this is expected sometimes.\n");
+ printf("Second cancellation failed but this is expected sometimes.\n");
}
}
@@ -24,9 +24,9 @@
* --------------------------------------------------------------------------
*
- * Test Synopsis: Test double cancelation - deferred.
+ * Test Synopsis: Test double cancellation - deferred.
* Second attempt should succeed (unless the canceled thread has started
@@ -24,9 +24,9 @@
* Second attempt should succeed (unless the canceled thread has started
- * cancelation already - not tested here).
+ * cancellation already - not tested here).
*
* Test Method (Validation or Falsification):
@@ -101,7 +101,7 @@ mythread(void * arg)
/*
* We wait up to 10 seconds, waking every 0.1 seconds,
- * for a cancelation to be applied to us.
+ * for a cancellation to be applied to us.
*/
for (bag->count = 0; bag->count < 100; bag->count++)